@media (min-width: 1025px) {
  	button,.btn, .sub-menu,*:before,*:after, a, .actu img, .item { transition: all ease-in-out 0.3s}
  	.btn:hover { background-position: center right+20px }
  	.produits .item:hover { box-shadow: 0 16px 21px rgba(1,1,1,.06); }
  	footer a:hover, .itemblog a:hover { color: #f2a950; }
  	.menu>li>a:hover { background: #f2a950; color:#fff; }
  	.autre-produits a:hover { box-shadow: 0 0 30px rgba(1,1,1,.1) }
	.organisme a:hover .front-title { -webkit-transform: rotateX(180deg); transform: rotateX(180deg); z-index: 1; }
	.organisme a:hover .back-description { -webkit-transform: rotateX(0deg); transform: rotateX(0deg);z-index: 2; }
}
@media (max-width: 1200px) {
  .menu>li>a { margin:0; }
  .banner .texte { margin-left: 0; }
  .produits .item .image span { bottom: -25px }
  .list-actu .itemblog { width: 50%; }
  .autre-produits .item { width: 50%; }
}
@media (max-width: 1024px) {
  .logo-nav { padding: 50px 0 27px; }
  .menu-toggle { cursor:pointer; position:absolute; width:20px; right:0; top:50px; bottom: 27px; z-index:140; }
  .menu-toggle div { width:20px; height:2px; background:#111111; position:absolute; right:0; left:0; top:50%; margin:-1px auto 0;}
  .menu-toggle div:before { width:100%; height:2px; background:#111111; position:absolute; right:0; top:6px; content:"";transition:all ease-in-out 0.3s;-moz-transition:all ease-in-out 0.3s;-webkit-transition:all ease-in-out 0.3s;}
  .menu-toggle div:after { width:100%; height:2px; background:#111111; position:absolute; right:0; top:-6px; content:"";transition:all ease-in-out 0.3s;-moz-transition:all ease-in-out 0.3s;-webkit-transition:all ease-in-out 0.3s;}
  .menu-toggle.active div { height:0;transition:all ease-in-out 0.3s;-moz-transition:all ease-in-out 0.3s;-webkit-transition:all ease-in-out 0.3s;}
  .menu-toggle.active div:before { top:0; transform:rotate(45deg);}
  .menu-toggle.active div:after { top:0; transform:rotate(-45deg);}
  .menu { display:none; position:absolute; left: -40px; right: -40px; background:#fff; text-align:left; top:113px; z-index: 555}
  .menu:after { content: ''; position: absolute; background: rgba(0,0,0,.8); left: 0; right: 0; height: 10000px; bottom: -10000px; }
  .menu>li { display:block; padding:0; margin: 0; }
  .menu>li>a { padding:0 40px; line-height:48px; border-bottom:1px solid #ebebeb; display: block; }
  .produits .flex { margin: 0 -15px; }
  .produits h2:after { margin: 20px auto 40px; }
  .produits .item { padding: 0 15px; }
}
@media (max-width: 980px){
.banner { background: #f6f6f6; border-bottom-left-radius: 50%; border-bottom-right-radius: 50%; margin: 0 -50px; padding-bottom: 50px }
.banner .image { display: none; }
.banner .texte { margin: 40px auto 60px }
.bloc-imagetexte .image { padding-right: 40px; }
.half.flex { margin: 0 -20px; }
.half.flex .texte { padding: 0 20px }

.bloc-imagetexte { margin: 40px 0; }
.bandeau, .half.flex, .bloc-imagetexte.no-marg, .comparateur .bg-gray { padding: 40px 0 }
.bienvenu { margin-top: 40px; }
.produits { padding-top: 40px; }
.produits .item { width: 50%; }
.autre-produits { padding: 30px 0 }

	.organisme .item { height:250px; width: 50%; }
	
.single .content { width:100%; padding-right: 0; }
.single .sidebar { width: 100%; text-align: center; }
.single .sidebar .similaire-liste { display: flex; flex-flow: row wrap; text-align: left; margin: 0 -20px; }
.single .similaire-liste .itemblog { padding: 0 20px; width: 50%; }
.single .similaire-liste .itemblog .absolute { left: 20px }
}
@media (max-width: 760px){
.banner .texte { max-width: 100%; margin-right: 50px; margin-left: 50px; }
.bloc-imagetexte .flex { flex-direction: column; }
.bloc-imagetexte .flex>div { width: 100%; }
.bloc-imagetexte .flex .image { padding: 0 0 20px }
.half.flex { margin: 0; }
.half.flex .texte { width: 100%; padding:0 0 20px }
.list-actu .itemblog { width: 100%; padding: 0; }
.list-actu { margin:0; }
.itemblog .absolute { left: 0; right: 0; }
.single .sidebar .similaire-liste { margin: 0; justify-content: center; }
.single .similaire-liste .itemblog { padding: 0; width: 100%; max-width: 375px }
.single .similaire-liste .itemblog .absolute { left: 0 }
.autre-produits .wrapper>.flex { justify-content: center; }
.autre-produits .item { max-width: 400px; width: 100%; }
}
@media(max-width: 640px) {
h1 { font-size: 22px; }
h2 { font-size: 20px; }
h2 { font-size: 18px; }
.bandeau .titre { font-size: 20px }
.top { font-size: 0; }
.wrapper { padding-right: 20px; padding-left: 20px; }
.produits .flex { margin: 0; }
.produits .item { width: 100%; padding: 0; }
.bloc-imagetexte.no-marg { padding: 20px 0; }
.btn.vert { text-align: center; padding: 0 29px; background-image: initial; }
.bienvenu { margin-top: 20px; }
.half.flex { padding-bottom: 20px; }
.itemblog .date { padding: 20px 10px }
.itemblog a { padding: 15px; padding-left: 60px; }
#PMCiframeMQBL { border: 1px solid #f1f1f1; padding: 15px; border-radius: 10px }
.flex.organisme .item { width: 100% }	
.single .content .image { margin-bottom: 20px; }
.single .sidebar .title { width: initial; }
.single .sidebar .title:before, .single .sidebar .title:after { display: none; }

form { padding:30px 0; }

footer .nav-footer.flex { flex-direction: column; align-items: center; }
footer ul { text-align: center; margin: 0 -8px }
footer ul li:before { display: none; }
footer ul li { margin-top: 10px; padding: 0 8px }
}
@media(max-width: 400px) {
	.btn.vert { padding: 0 12px}
	.autre-produits .item .icone { display: none; }
	.autre-produits .item .texte { width: 100%;padding: 0; }
}