<div class="bandeau">
    <div>
        <div class="titre"><?php the_field('titre_bandeau', 9); ?></div>
        <a href="<?php the_permalink(131) ?>" class="btn vert">Comparateur de credit</a>
    </div>
</div>