/*
Theme Name: Organisme de crédit
Author: Media Click
Author URI: https://mediaclick.mg
Version: 1.0
*/

@font-face {
  font-family: 'karlabold';
  src:  url('fonts/karlabold.eot?#iefix') format('embedded-opentype'),
      url('fonts/karlabold.woff') format('woff'),
      url('fonts/karlabold.ttf')  format('truetype'),
      url('fonts/karlabold.svg#Karla-Bold') format('svg');
  font-weight: normal;
  font-style: normal;
}
@font-face {
  font-family: 'latobold';
  src:  url('fonts/latobold.eot?#iefix') format('embedded-opentype'),
      url('fonts/latobold.woff') format('woff'), 
      url('fonts/latobold.ttf')  format('truetype'), 
      url('fonts/latobold.svg#Lato-Bold') format('svg');
  font-weight: normal;
  font-style: normal;
}
@font-face {
  font-family: 'latoreg';
  src:  url('fonts/latoregular.eot?#iefix') format('embedded-opentype'),
      url('fonts/latoregular.woff') format('woff'), 
      url('fonts/latoregular.ttf') format('truetype'), 
      url('fonts/latoregular.svg#Lato-Regular') format('svg');
  font-weight: normal;
  font-style: normal;
}

body, ul, li, ol, form, h1, h2, h3, h4, h5, h6, div, span, p { padding:0; margin:0; border:0; -webkit-text-size-adjust:none; -moz-text-size-adjust:none; text-size-adjust:none;}
article, aside, dialog ,figcaption, figure, footer, header, hgroup, main, nav, section { display:block;}  
input, textarea{ -webkit-appearance:none; -ms-appearance:none; appearance:none; -moz-appearance:none; -o-appearance:none; border-radius:0;}
*{ outline:none !important;}
strong, b{ font-weight:normal; font-family:latobold;}
ul{ list-style-type:none;}
body{ font:normal 14px/23px latoreg; color:#6d6d6d; }
a{ text-decoration:none; color:#f2a950; transition:all ease-in-out 400ms; position:relative;}
img{ border:none; display:block;}
#wrapper{ overflow:hidden; }
h1,h2 { position: relative; }
h1 { font: 25px/29px karlabold; color: #f2a950; }
h2 { font: 22px/29px karlabold; color: #432c82; margin-bottom: 20px; }
h3 { font: 18px/26px karlabold; color: #f2a950; margin-bottom: 8px; }
*{ box-sizing:border-box;}
p { margin-bottom: 20px; text-align: justify; }
p:last-of-type { margin-bottom: 0; }
.bg-gray { background: #f2f2f2; }
.flex { display: flex; flex-flow: row wrap; }
.btn { display: inline-block; color: #fff; font: 16px/16px latoreg; text-transform: uppercase; box-shadow: 0 16px 21px rgba(1,1,1,.06); }
.btn.vert { line-height: 50px; background: url('images/iconebtn.svg') no-repeat right+27px center #87d27f; padding: 0 80px 0 40px }
.texte ul { margin: 25px 0 25px 50px; }
.texte ul li { padding-left: 25px; padding-bottom: 10px; background: url(images/liste.svg) no-repeat left top+5px; }
.wrapper { width:100%; max-width:1240px; margin:0 auto; padding:0 40px; position:relative;}
header { position: relative; }
.top { position: relative; display: flex; justify-content: space-between; background: #432c82; color: #fff; font: 14px/45px latoreg; padding-left: 29px; bottom: -20px; z-index: 55; box-shadow: 0 16px 21px rgba(1,1,1,.06); }
.top .btn { background: url(images/iconebtntop.svg) no-repeat center right+30px #f2a950; padding: 16px 60px 13px 30px; }
.logo-nav { display: flex; justify-content: space-between; align-items: center; padding: 58px 0 35px; background: #f6f6f6; position: relative; }
.logo-nav:before { content:''; position: absolute; left: -10000px; width: 10000px; background: #f6f6f6; top: 0; bottom: 0; }
.logo-nav:after { content:''; position: absolute; right: -10000px; width: 10000px; background: #f6f6f6; top: 0; bottom: 0; }
.custom-logo-link { height: 40px; }
.custom-logo-link img { height:100%; }
.menu { display: flex; }
.menu>li>a { display: inline-block; font: 16px/45px latoreg; position: relative; padding: 0 20px; margin: 0 20px; color: #6d6d6d; text-transform: uppercase; }
.menu>li.current-menu-item>a { background: #f2a950; color: #fff; }
.menu>li.current-menu-item>a:after { width: 100%; }
.menu>li:last-child>a { margin-right: 0; }
.banner { background: url(images/banner-form.svg) no-repeat left bottom; background-size: cover; margin-bottom: 110px; }
.banner .texte { max-width: 390px; margin-left: 90px; margin-top: 40px }
.banner .texte li { font: 16px/23px latoreg; text-transform: uppercase; color: #432c82; }
.banner .image { margin: 0 auto -70px; }
.banner .image img { width: 100%; height: auto; object-fit: cover; }
.bloc-imagetexte { margin: 60px 0; }
.bloc-imagetexte .flex { align-items: center; }
.bloc-imagetexte .flex>div { width: 50%; }
.bloc-imagetexte.reverse .flex { flex-direction: row-reverse; }
.bloc-imagetexte .image { padding-right: 60px; }
.bloc-imagetexte.reverse .image { padding-left:60px; padding-right: 0; }
.bloc-imagetexte .image img{ width: 100%; height: auto; object-fit: cover; box-shadow: 0 16px 21px rgba(1,1,1,.06); }
.bandeau { background:#432c82; padding: 50px 0 }
.bandeau .titre { font: 22px/29px karlabold; color: #f2a950; margin-bottom: 30px; }
.bandeau>div { max-width: 535px; padding: 0 20px; text-align: center; margin: auto; }
.half.flex { margin: 0 -40px; padding: 60px 0 }
.half.flex .texte{ width: 50%; padding: 0 40px; }
.produits { padding-top: 50px; }
.produits .title, .autre-produits .title { text-align: center; font: 22px/29px karlabold; color: #432c82; }
.produits .title:after { content: ''; width: 48px; height: 2px; background: #f2a950; display: block; margin:30px auto 60px; }
.produits .flex { margin: 0 -30px; }
.produits .item { width: 33.33%; padding: 0 30px 20px; margin-bottom: 50px }
.produits .item .image>img { width: 100%; height: auto; object-fit: cover; }
.produits .item .image { position: relative; }
.produits .item .image span { position: absolute; right: 20px; bottom: -45px; display: inline-block; width: 90px; height: 90px; background: #fff; border-radius: 50%; box-shadow: 0 16px 21px rgba(1,1,1,.06); }
.produits .item .image span img { position: absolute; top: 0; bottom: 0; right: 0; left: 0; margin:auto; }
.produits .item a { font: 18px/22px karlabold; margin: 30px 0 15px; display: block; color: #432c82; }
.bloc-imagetexte.no-marg { padding: 60px 0; margin: 0; }

.autre-produits { padding: 50px 0 }
.autre-produits .title:after { content: ''; width: 48px; height: 2px; background: #f2a950; display: block; margin:20px auto }
.autre-produits .wrapper>.flex { margin: 0 -15px; justify-content:center }
.autre-produits .item { width: 33.33%; padding: 15px; }
.autre-produits .item>.flex { border: 1px solid #f0f0f0; padding: 15px; align-items: center; }
.autre-produits .item .icone { position: relative; display: inline-block; width: 90px; height: 90px; background: #fff; border-radius: 50%; box-shadow: 0 16px 21px rgba(1,1,1,.06); }
.autre-produits .item .icone img { position: absolute; top: 0; bottom: 0; right: 0; left: 0; margin:auto; }
.autre-produits .item .texte { width: calc(100% - 90px); padding-left: 15px; color: #6d6d6d }
.autre-produits .item .titre { font: 18px/22px karlabold; color: #432c82; margin-bottom: 10px; }

.breadcrumbs { padding: 20px 0; }
.breadcrumbs a { color: #6d6d6d; }
.breadcrumbs a:after { content:'>'; display: inline-block; margin: 0 15px; }
.breadcrumb_last { color: #f2a950; }
.bienvenu { margin-top: 50px }
.bienvenu h1 { margin-bottom: 17px; }
.comparateur .bienvenu, .comparateur .bienvenu p { margin-bottom: 50px; text-align: center; }
.comparateur .bg-gray { padding: 60px 0; }
.blog .bienvenu { margin: 0 0 50px; text-align: center; }
.list-actu { margin: 0 -30px; }
.list-actu .itemblog { width: 33.33%; padding: 0 30px; position: relative; margin-bottom: 65px; }
.itemblog img { width: 100%; height: auto; object-fit: cover; padding-left: 20px; }
.itemblog .absolute { position: absolute; left: 30px; right: 50px; bottom: -20px; background: #fff; display: flex; align-items: center; min-height: 86px; box-shadow: 0 16px 21px rgba(1,1,1,.06); }
.date span { font: 25px/25px karlabold; display: block; }
.date { font: 16px/19px karlabold; position: absolute; top: 0; bottom: 0; text-align: center; background: #432c82; padding: 20px 25px; color: #fff; }
.itemblog a { display: inline-block; font: 16px/22px karlabold; padding: 15px 20px; padding-left: 100px; color: #432c82; }
.single .content { width: calc( 100% - 350px ); padding-right: 50px; padding-bottom: 80px }
.single .content h1 { margin-bottom: 33px; }
.single .content .image { position: relative; margin-bottom: 40px }
.single .content .image img { width: 100%; height: auto; object-fit: cover; }
.single .content .image .date { top: initial; height: 80px; }
.single .sidebar { width: 350px; }
.single .sidebar .title { display: inline-block; width: 350px; text-align: center; position: relative; font: 22px/29px karlabold; color: #432c82; margin-bottom: 35px }
.single .sidebar .title:before { content: ''; position: absolute; width: 26px; height: 2px; background: #f2a950; left: 0; top: 50%; margin-top: -1px; }
.single .sidebar .title:after { content: ''; position: absolute; width: 26px; height: 2px; background: #f2a950; right: 0; top: 50%; margin-top: -1px; }
.single .sidebar .itemblog { position: relative; margin-bottom: 60px; padding-left: 15px; }
.single .sidebar .itemblog .absolute { left: 0; right: 20px; }

.contact .bienvenu { text-align: center; }
.contact .bienvenu p { text-align: center; }
.wrap-contact { max-width: 620px; padding: 0 20px; margin: auto; }
.wrap-contact form { width: 100%; display:block; }
div.wpforms-container-full .wpforms-form .wpforms-error-container { border: 1px solid #f2a950; padding: 15px; }
form { padding:20px 0 80px; }
.wrap-contact form input, textarea { display: block; width: 100% ! important; border: 1px solid #cecece !important; padding: 10px 15px !important; font: 14px/14px karlabold !important; }
textarea.wpforms-field-medium{ height: 200px !important; resize: none; }
form input::placeholder, textarea::placeholder { color: #c8c8c8; }
.wrap-contact .btn.vert { background-color: #f2a950; cursor: pointer; border:none; }
.wpforms-submit-container { text-align: center; }
.wpforms-confirmation-container-full.wpforms-confirmation-scroll { margin: 40px 0; }
.wpforms-confirmation-container-full.wpforms-confirmation-scroll p{ text-align: center; }

.pagesimple #breadcrumbs { margin: 0; padding-bottom: 0; }
.height { display: table; height: 60vh; width: 100%; }
.height>div { display:table-cell; vertical-align:middle; text-align:center; font-size: 30px; }
.height>div span { display:block; font: 120px/120px latobold; text-align:center; color:#f2a950; }

.mention { margin: 0 0 40px; }
.mention h1 { margin-bottom: 10px }

footer .nav-footer { justify-content: center; padding: 40px 20px }
footer .info { background: #432c82; padding: 17px 40px; text-align: center; color: #fff; }
footer .info-site, footer ul li a{ color: #432c82; }
footer ul li:before { display: inline-block; content: '|'; vertical-align: middle; margin: 0 20px; }

/****************/
.titresspage { text-align:center;font: 22px/29px karlabold; color: #432c82; padding-top:40px; }
.page-parent h1, .souspage h1 { margin-bottom: 20px }
.souspage .logo { margin-bottom: 30px; max-height:100px }
.organisme.flex { margin: 0 -8px; padding: 10px 0 40px; }
.organisme .item { width: 33.33%; height: 300px; padding: 20px 8px; }
.organisme .item a { display: block; width: 100%; height: 100%; -webkit-transform-style: preserve-3d; transform-style: preserve-3d; -webkit-transition: all 1s linear; transition: all 1s linear }
.front-title { display:table; -webkit-transform: rotateX(0deg); transform: rotateX(0deg); z-index: 2; }
.face { position: absolute; width: 100%; height: 100%; -webkit-backface-visibility: hidden; backface-visibility: hidden; -webkit-transform-style: preserve-3d; transform-style: preserve-3d; -webkit-transition: .35s; transition: .35s; }
.face>div { text-align:center; padding:30px 20px; background-color: #fff; border: 1px solid #f5f5f5; }
.container-front { display:table-cell; vertical-align:middle; }
.container-front img { display: block; margin: 0 auto; max-height: 130px }
.container-back { position:relative; top:50%; transform:translateY(-50%); box-shadow: 0 14px 14px rgba(0,0,0,.02); }
.container-back p { text-align:center; font:14px/23px latoreg; color: #6d6d6d }
.back-description { display: block; -webkit-transform: rotateX(-180deg); transform: rotateX(-180deg); border-radius: 2px; z-index: 1; }

.bloc-imagetexte .logo { max-height:50px; max-width: 100px; margin-bottom: 20px }
#PMCiframeMQBL { max-width: 668px; margin: 0 auto }
.wp-pagenavi { text-align: center; margin: 0 0 40px; font-size: 16px }
.wp-pagenavi .pages { display: none; }
.wp-pagenavi .page, .wp-pagenavi .current { display: inline-block; margin: 0 10px }